package com.usky.system.service;

import com.usky.common.core.bean.CommonPage;
import com.usky.common.mybatis.core.CrudService;
import com.usky.system.domain.SysUser;
import com.usky.system.model.LoginUser;
import com.usky.system.service.vo.SysUserNewVO;
import com.usky.system.service.vo.TenantPlatformMenuVo;

import java.util.List;

/**
 * 用户 业务层
 *
 * @author yq
 */
public interface ISysUserService extends CrudService<SysUser> {
    /**
     * 根据条件分页查询用户列表
     *
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    public List<SysUser> selectUserList(SysUser user);


    List<SysUser> platAccountlist(SysUser user);

    /**
     * 根据条件分页查询用户列表
     *
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    public List<SysUser> selectDUserList(SysUser user);

    /**
     * 查询用户列表 - new
     *
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    List<SysUserNewVO> dUserList(SysUser user);

    /**
     * 根据条件分页查询已分配用户角色列表
     *
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    public List<SysUser> selectAllocatedList(SysUser user);

    /**
     * 根据条件分页查询未分配用户角色列表
     *
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    public List<SysUser> selectUnallocatedList(SysUser user);

    /**
     * 通过用户名查询用户
     *
     * @param userName 用户名
     * @return 用户对象信息
     */
    public SysUser selectUserByUserName(String userName);

    public SysUser selectUserByUserNameOne(String userName,Integer tenantId);

    /**
     * 通过用户ID查询用户
     *
     * @param userId 用户ID
     * @return 用户对象信息
     */
    public SysUser selectUserById(Long userId);

    public SysUser selectUserByIdOne(Long userId);

    /**
     * 根据用户ID查询用户所属角色组
     *
     * @param userName 用户名
     * @return 结果
     */
    public String selectUserRoleGroup(String userName);

    /**
     * 根据用户ID查询用户所属岗位组
     *
     * @param userName 用户名
     * @return 结果
     */
    public String selectUserPostGroup(String userName);

    /**
     * 校验用户名称是否唯一
     *
     * @param userName 用户名称
     * @return 结果
     */
    public String checkUserNameUnique(String userName,Integer tenantId);

    /**
     * 校验手机号码是否唯一
     *
     * @param user 用户信息
     * @return 结果
     */
    public String checkPhoneUnique(SysUser user);

    /**
     * 校验手机号码是否唯一
     *
     * @param phone 手机号
     * @param tenantId 租户ID
     * @return 结果
     */
    public String checkPhoneUnique1(String phone, Integer tenantId);

    /**
     * 校验email是否唯一
     *
     * @param user 用户信息
     * @return 结果
     */
    public String checkEmailUnique(SysUser user);

    /**
     * 校验email是否唯一
     *
     * @param email 用户邮箱
     * @param tenantId 租户ID
     * @return 结果
     */
    public String checkEmailUnique1(String email, Integer tenantId);

    /**
     * 校验用户是否允许操作
     *
     * @param user 用户信息
     */
    public void checkUserAllowed(SysUser user);

    /**
     * 新增用户信息
     *
     * @param user 用户信息
     * @return 结果
     */
    public int insertUser(SysUser user);

    /**
     * 新增平台账号信息
     *
     * @param user 平台账号信息
     * @return 结果
     */
    public int insertPlatAccount(SysUser user);

    /**
     * 注册用户信息
     *
     * @param user 用户信息
     * @return 结果
     */
    public boolean registerUser(SysUser user);

    /**
     * 修改用户信息
     *
     * @param user 用户信息
     * @return 结果
     */
    public int updateUser(SysUser user);


    /**
     * 修改运维管理系统-平台账号信息
     *
     * @param user 用户信息
     * @return 结果
     */
    public int updatePlatAccount(SysUser user);

    /**
     * 用户授权角色
     *
     * @param userId  用户ID
     * @param roleIds 角色组
     */
    public void insertUserAuth(Long userId, Long[] roleIds);

    /**
     * 修改用户状态
     *
     * @param user 用户信息
     * @return 结果
     */
    public int updateUserStatus(SysUser user);

    /**
     * 修改用户基本信息
     *
     * @param user 用户信息
     * @return 结果
     */
    public int updateUserProfile(SysUser user);

    /**
     * 修改用户头像
     *
     * @param userName 用户名
     * @param avatar   头像地址
     * @return 结果
     */
    public boolean updateUserAvatar(String userName, String avatar);

    /**
     * 重置用户密码
     *
     * @param user 用户信息
     * @return 结果
     */
    public int resetPwd(SysUser user);

    /**
     * 重置用户密码
     *
     * @param userName 用户名
     * @param password 密码
     * @return 结果
     */
    public int resetUserPwd(String userName, String password);

    /**
     * 通过用户ID删除用户
     *
     * @param userId 用户ID
     * @return 结果
     */
    public int deleteUserById(Long userId);

    /**
     * 批量删除用户信息
     *
     * @param userIds 需要删除的用户ID
     * @return 结果
     */
    public int deleteUserByIds(Long[] userIds);

    /**
     * 通过用户ID、密码删除用户
     *
     * @param userId 用户ID
     * @param password 用户ID
     * @return 结果
     */
    public int deleteUserByPwd(Long userId,String password);

    public LoginUser getUserInfo(String username);

    public LoginUser getUserInfoOne(String username,Integer tenantId);

    SysUser getAppUserInfo(String username, Integer tenantId,String phone,String method);
    
    public Boolean register(SysUser sysUser);

    public int addUser(SysUser user);


    public int updateUserData(SysUser user);

    public int resetUserPwdOne(Long userId, String password);

    public CommonPage<SysUser> userList(Integer tenantId, Integer page, Integer size, long userId, String nickName);

    public List<SysUser> userList();

    public List<SysUser> userByIdList(List<Integer> userIds);

    public List<SysUser> userAllList();

    /**
     * 根据手机号、用户名、邮箱查询用户信息
     * @return 用户列表
     */
    List<SysUser> selectUserOne(String phonenumber,String userName,String email);

}
