package com.usky.system.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.common.core.constants.Constants;
import com.usky.common.core.util.StringUtils;
import com.usky.common.security.utils.SecurityUtils;
import com.usky.system.controller.web.SysMenuController;
import com.usky.system.domain.*;
import com.usky.system.domain.constants.UserConstants;
import com.usky.system.mapper.*;
import com.usky.system.service.SysMobileMenuService;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.system.service.SysMobileTenantMenuService;
import com.usky.system.service.SysTenantService;
import com.usky.system.service.vo.MetaVo;
import com.usky.system.service.vo.RouterVo;
import com.usky.system.service.vo.TreeMobileSelect;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
 * <p>
 * 移动端_菜单权限表 服务实现类
 * </p>
 *
 * @author JCB
 * @since 2022-08-11
 */
@Service
public class SysMobileMenuServiceImpl extends AbstractCrudService<SysMobileMenuMapper, SysMobileMenu> implements SysMobileMenuService {

    @Autowired
    private SysMobileMenuMapper sysMobileMenuMapper;

    @Autowired
    private  SysMobileTenantMenuMapper sysMobileTenantMenuMapper;

    @Autowired
    private SysMobileTenantMenuService sysMobileTenantMenuService;

    @Autowired
    private SysRoleMenuMapper sysRoleMenuMapper;

    @Autowired
    private SysRoleMapper roleMapper;

    @Autowired
    private SysUserRoleMapper sysUserRoleMapper;

    @Autowired
    private SysUserMapper sysUserMapper;

    @Autowired
    private SysMobileRoleMenuMapper sysMobileRoleMenuMapper;

    /**
     * 查询系统菜单列表
     *
     * @param menu 菜单信息
     * @return 菜单列表
     */
    @Override
    public List<SysMobileMenu> selectMobileMenuList(SysMobileMenu menu, Long userId)
    {
        List<SysMobileMenu> menuList = null;
        // 管理员显示所有菜单信息
        if (SysUserVO.isAdmin(userId))
        {
            menuList = sysMobileMenuMapper.selectMobileMenuList(menu);
        }
        else
        {
            menu.getParams().put("userId", userId);
            menuList = sysMobileMenuMapper.selectMobileMenuListByUserId(menu);
        }
        return menuList;
    }

    /**
     * 构建前端所需要树结构
     *
     * @param menus 菜单列表
     * @return 树结构列表
     */
    @Override
    public List<SysMobileMenu> buildMenuTree(List<SysMobileMenu> menus)
    {
        List<SysMobileMenu> returnList = new ArrayList<SysMobileMenu>();
        List<Long> tempList = new ArrayList<Long>();
        for (SysMobileMenu dept : menus)
        {
            tempList.add(dept.getMenuId());
        }
        for (Iterator<SysMobileMenu> iterator = menus.iterator(); iterator.hasNext();)
        {
            SysMobileMenu menu = (SysMobileMenu) iterator.next();
            // 如果是顶级节点, 遍历该父节点的所有子节点
            if (!tempList.contains(menu.getParentId()))
            {
                recursionFn(menus, menu);
                returnList.add(menu);
            }
        }
        if (returnList.isEmpty())
        {
            returnList = menus;
        }
        return returnList;
    }

    @Override
    public List<SysMobileMenu> selectMenuListTwo(){
        List<SysMobileMenu> list = sysMobileMenuMapper.selectMenuListOne(SecurityUtils.getTenantId());
        return list;
    }

    /**
     * 构建前端所需要下拉树结构
     *
     * @param menus 菜单列表
     * @return 下拉树结构列表
     */
    @Override
    public List<TreeMobileSelect> buildMenuTreeSelect(List<SysMobileMenu> menus)
    {
        List<SysMobileMenu> menuTrees = buildMenuTree(menus);
        return menuTrees.stream().map(TreeMobileSelect::new).collect(Collectors.toList());
    }

    /**
     * 根据菜单ID查询信息
     *
     * @param menuId 菜单ID
     * @return 菜单信息
     */
    @Override
    public SysMobileMenu selectMenuById(Long menuId)
    {
        return sysMobileMenuMapper.selectMenuById(menuId);
    }

    /**
     * 修改保存菜单信息
     *
     * @param menu 菜单信息
     * @return 结果
     */
    @Override
    public int updateMenu(SysMobileMenu menu)
    {
        return sysMobileMenuMapper.updateMenu(menu);
    }

    /**
     * 删除菜单管理信息
     *
     * @param menuId 菜单ID
     * @return 结果
     */
    @Override
    public int deleteMenuById(Long menuId)
    {
        return sysMobileMenuMapper.deleteMenuById(menuId);
    }

    /**
     * 校验菜单名称是否唯一
     *
     * @param menu 菜单信息
     * @return 结果
     */
    @Override
    public String checkMenuNameUnique(SysMobileMenu menu)
    {
        Long menuId = Objects.isNull(menu.getMenuId()) ? -1L : menu.getMenuId();
        SysMobileMenu info = sysMobileMenuMapper.checkMobileMenuNameUnique(menu.getMenuName(), menu.getParentId());
        if (Objects.nonNull(info) && info.getMenuId() != menuId.longValue())
        {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;
    }

    /**
     * 新增保存菜单信息
     *
     * @param menu 菜单信息
     * @return 结果
     */
    @Override
    public int insertMobileMenu(SysMobileMenu menu)
    {
        return sysMobileMenuMapper.insertMobileMenu(menu);
    }

    @Override
    public List<SysMobileMenu> moveRoute(){
        List<SysMobileMenu> list = new ArrayList<>();
        LambdaQueryWrapper<SysMobileTenantMenu> query = Wrappers.lambdaQuery();
        query.eq(SysMobileTenantMenu::getTenantId, SecurityUtils.getTenantId());
        List<SysMobileTenantMenu> tenantMenuList = sysMobileTenantMenuService.list(query);
        if (CollectionUtils.isNotEmpty(tenantMenuList)){
            List<Long> menuIdList = new ArrayList<>();
            for (int i = 0; i < tenantMenuList.size(); i++) {
                menuIdList.add(tenantMenuList.get(i).getMenuId());
            }
            LambdaQueryWrapper<SysMobileMenu> queryOne = Wrappers.lambdaQuery();
            queryOne.in(SysMobileMenu::getMenuId, menuIdList)
                    .eq(SysMobileMenu::getVisible,0)
                    .eq(SysMobileMenu::getStatus,0);
            queryOne.orderByAsc(SysMobileMenu::getOrderNum);
            List<SysMobileMenu> menuList = this.list(queryOne);
            list = getChildPerms(menuList, 0);
        }
        return list;
    }


    /**
     * 根据用户ID查询菜单
     *
     * @param userId 用户名称
     * @return 菜单列表
     */
    @Override
    public List<SysMobileMenu> selectMenuTreeByUserId(Long userId)
    {
        List<SysMobileMenu> menus = null;
        if (1L == userId)
        {
            menus = sysMobileMenuMapper.selectMenuTreeAll();
        }
        else
        {
            menus = sysMobileMenuMapper.selectMenuTreeByUserId(userId);
        }
        return getChildPerms(menus, 0);
    }


    @Override
    public List<SysMobileMenu> selectMenuTreeByUserIdOne(Integer tenantId){
        List<SysMobileMenu> menus = sysMobileMenuMapper.selectMenuTreeByUserIdOne(tenantId);
        return getChildPerms(menus, 0);
    }

    @Override
    public List<SysMobileTenantMenu> getMobileTenantMenuList(Integer tenantId){
        List<SysMobileTenantMenu> menus = sysMobileTenantMenuMapper.getMobileTenantMenuList(tenantId);
        return menus;
    }

    @Override
    public void updateMobileTenantMenu(SysMobileTenantMenu mobileTenantMenu){
        UpdateWrapper<SysMobileTenantMenu> updateWrapper = Wrappers.update();
        updateWrapper.set("menu_alias_name",mobileTenantMenu.getMenuAliasName())
                .eq("tenant_id",mobileTenantMenu.getTenantId())
                .eq("menu_id",mobileTenantMenu.getMenuId());
        sysMobileTenantMenuService.update(updateWrapper);



        LambdaQueryWrapper<SysUser> queryWrapper1 = Wrappers.lambdaQuery();
        queryWrapper1.select(SysUser::getUserId)
                .eq(SysUser::getStatus,0)
                .eq(SysUser::getDelFlag,0)
                .eq(SysUser::getTenantId,SecurityUtils.getTenantId());
        List<SysUser> list = sysUserMapper.selectList(queryWrapper1);
        List<Long> userIdList = new ArrayList<>();
        if(CollectionUtils.isNotEmpty(list)){
            for (int i = 0; i < list.size(); i++) {
                userIdList.add(list.get(i).getUserId());
            }
        }

        if(userIdList.size() > 0){
            LambdaQueryWrapper<SysUserRole> queryWrapper = Wrappers.lambdaQuery();
            queryWrapper.in(SysUserRole::getUserId,userIdList);
            List<SysUserRole> userRoleList = sysUserRoleMapper.selectList(queryWrapper);
            List<Long> roleIdList = new ArrayList<>();
            if(userRoleList.size() > 0){
                for (int i = 0; i < userRoleList.size(); i++) {
                    if(roleIdList.contains(userRoleList.get(i).getRoleId())){

                    }else{
                        roleIdList.add(userRoleList.get(i).getRoleId());
                    }
                }
            }

            if(roleIdList.size() > 0){
                UpdateWrapper<SysMobileRoleMenu> updateWrapper1 = Wrappers.update();
                updateWrapper1.set("menu_alias_name",mobileTenantMenu.getMenuAliasName())
                        .in("role_id",roleIdList)
                        .eq("menu_id",mobileTenantMenu.getMenuId());
                sysMobileRoleMenuMapper.update(null,updateWrapper1);
            }

        }
    }

    /**
     * 根据角色ID查询菜单树信息
     *
     * @param roleId 角色ID
     * @return 选中菜单列表
     */
    @Override
    public List<Integer> selectMenuListByRoleId(Long roleId)
    {
        SysRole role = roleMapper.selectRoleById(roleId);
        return sysMobileMenuMapper.selectMenuListByRoleId(roleId, role.isMenuCheckStrictly());
    }

    /**
     * 构建前端路由所需要的菜单
     *
     * @param menus 菜单列表
     * @return 路由列表
     */
    @Override
    public List<RouterVo> buildMenus(List<SysMobileMenu> menus)
    {
        List<RouterVo> routers = new LinkedList<RouterVo>();
        for (SysMobileMenu menu : menus)
        {
            RouterVo router = new RouterVo();
            router.setHidden("1".equals(menu.getVisible()));
            router.setName(getRouteName(menu));
            router.setPath(getRouterPath(menu));
            router.setComponent(getComponent(menu));
            router.setMeta(new MetaVo(menu.getMenuName(), menu.getMenuAliasName(), menu.getIcon(), StringUtils.equals("1", menu.getIsCache()), menu.getPath(), menu.getRemark()));
            List<SysMobileMenu> cMenus = menu.getChildren();
            if (!cMenus.isEmpty() && cMenus.size() > 0 && UserConstants.TYPE_DIR.equals(menu.getMenuType()))
            {
                router.setAlwaysShow(true);
                router.setRedirect("noRedirect");
                router.setChildren(buildMenus(cMenus));
            }
            else if (isMenuFrame(menu))
            {
                router.setMeta(null);
                List<RouterVo> childrenList = new ArrayList<RouterVo>();
                RouterVo children = new RouterVo();
                children.setPath(menu.getPath());
                children.setComponent(menu.getComponent());
                children.setName(StringUtils.capitalize(menu.getPath()));
                children.setMeta(new MetaVo(menu.getMenuName(), menu.getMenuAliasName(), menu.getIcon(), StringUtils.equals("1", menu.getIsCache()), menu.getPath(), menu.getRemark()));
                childrenList.add(children);
                router.setChildren(childrenList);
            }
            else if (menu.getParentId().intValue() == 0 && isInnerLink(menu))
            {
                router.setMeta(new MetaVo(menu.getMenuName(), menu.getMenuAliasName(), menu.getIcon(), menu.getRemark()));
                router.setPath("/inner");
                List<RouterVo> childrenList = new ArrayList<RouterVo>();
                RouterVo children = new RouterVo();
                String routerPath = StringUtils.replaceEach(menu.getPath(), new String[] { Constants.HTTP, Constants.HTTPS }, new String[] { "", "" });
                children.setPath(routerPath);
                children.setComponent(UserConstants.INNER_LINK);
                children.setName(StringUtils.capitalize(routerPath));
                children.setMeta(new MetaVo(menu.getMenuName(), menu.getMenuAliasName(), menu.getIcon(), menu.getPath()));
                childrenList.add(children);
                router.setChildren(childrenList);
            }
            routers.add(router);
        }
        return routers;
    }

    /**
     * 是否存在菜单子节点
     *
     * @param menuId 菜单ID
     * @return 结果
     */
    @Override
    public boolean hasChildByMenuId(Long menuId)
    {
        int result = sysMobileMenuMapper.hasChildByMenuId(menuId);
        return result > 0 ? true : false;
    }

    /**
     * 查询菜单使用数量
     *
     * @param menuId 菜单ID
     * @return 结果
     */
    @Override
    public boolean checkMenuExistRole(Long menuId)
    {
        int result = sysRoleMenuMapper.checkMenuExistRole(menuId);
        return result > 0 ? true : false;
    }

    /**
     * 根据父节点的ID获取所有子节点
     *
     * @param list 分类表
     * @param parentId 传入的父节点ID
     * @return String
     */
    public List<SysMobileMenu> getChildPerms(List<SysMobileMenu> list, int parentId)
    {
        List<SysMobileMenu> returnList = new ArrayList<SysMobileMenu>();
        for (Iterator<SysMobileMenu> iterator = list.iterator(); iterator.hasNext();)
        {
            SysMobileMenu t = (SysMobileMenu) iterator.next();
            // 一、根据传入的某个父节点ID,遍历该父节点的所有子节点
            if (t.getParentId() == parentId)
            {
                recursionFn(list, t);
                returnList.add(t);
            }
        }
        return returnList;
    }


    /**
     * 递归列表
     *
     * @param list
     * @param t
     */
    private void recursionFn(List<SysMobileMenu> list, SysMobileMenu t)
    {
        // 得到子节点列表
        List<SysMobileMenu> childList = getChildList(list, t);
        t.setChildren(childList);
        for (SysMobileMenu tChild : childList)
        {
            if (hasChild(list, tChild))
            {
                recursionFn(list, tChild);
            }
        }
    }

    /**
     * 得到子节点列表
     */
    private List<SysMobileMenu> getChildList(List<SysMobileMenu> list, SysMobileMenu t)
    {
        List<SysMobileMenu> tlist = new ArrayList<SysMobileMenu>();
        Iterator<SysMobileMenu> it = list.iterator();
        while (it.hasNext())
        {
            SysMobileMenu n = (SysMobileMenu) it.next();
            if (n.getParentId().longValue() == t.getMenuId())
            {
                tlist.add(n);
            }
        }
        return tlist;
    }

    /**
     * 判断是否有子节点
     */
    private boolean hasChild(List<SysMobileMenu> list, SysMobileMenu t)
    {
        return getChildList(list, t).size() > 0 ? true : false;
    }

    /**
     * 获取路由名称
     *
     * @param menu 菜单信息
     * @return 路由名称
     */
    public String getRouteName(SysMobileMenu menu)
    {
        String routerName = StringUtils.capitalize(menu.getPath());
        // 非外链并且是一级目录（类型为目录）
        if (isMenuFrame(menu))
        {
            routerName = StringUtils.EMPTY;
        }
        return routerName;
    }

    /**
     * 获取路由地址
     *
     * @param menu 菜单信息
     * @return 路由地址
     */
    public String getRouterPath(SysMobileMenu menu)
    {
        String routerPath = menu.getPath();
        // 内链打开外网方式
        if (menu.getParentId().intValue() != 0 && isInnerLink(menu))
        {
            routerPath = StringUtils.replaceEach(routerPath, new String[] { Constants.HTTP, Constants.HTTPS }, new String[] { "", "" });
        }
        // 非外链并且是一级目录（类型为目录）
        if (0 == menu.getParentId().intValue() && UserConstants.TYPE_DIR.equals(menu.getMenuType())
                && UserConstants.NO_FRAME.equals(menu.getIsFrame()))
        {
            routerPath = "/" + menu.getPath();
        }
        // 非外链并且是一级目录（类型为菜单）
        else if (isMenuFrame(menu))
        {
            routerPath = "/";
        }
        return routerPath;
    }

    /**
     * 获取组件信息
     *
     * @param menu 菜单信息
     * @return 组件信息
     */
    public String getComponent(SysMobileMenu menu)
    {
        String component = UserConstants.LAYOUT;
        if (StringUtils.isNotEmpty(menu.getComponent()) && !isMenuFrame(menu))
        {
            component = menu.getComponent();
        }
        else if (StringUtils.isEmpty(menu.getComponent()) && menu.getParentId().intValue() != 0 && isInnerLink(menu))
        {
            component = UserConstants.INNER_LINK;
        }
        else if (StringUtils.isEmpty(menu.getComponent()) && isParentView(menu))
        {
            component = UserConstants.PARENT_VIEW;
        }
        return component;
    }

    /**
     * 是否为菜单内部跳转
     *
     * @param menu 菜单信息
     * @return 结果
     */
    public boolean isMenuFrame(SysMobileMenu menu)
    {
        return menu.getParentId().intValue() == 0 && UserConstants.TYPE_MENU.equals(menu.getMenuType())
                && menu.getIsFrame().equals(UserConstants.NO_FRAME);
    }

    /**
     * 是否为内链组件
     *
     * @param menu 菜单信息
     * @return 结果
     */
    public boolean isInnerLink(SysMobileMenu menu)
    {
        return menu.getIsFrame().equals(UserConstants.NO_FRAME) && StringUtils.startsWithAny(menu.getPath(), Constants.HTTP, Constants.HTTPS);
    }

    /**
     * 是否为parent_view组件
     *
     * @param menu 菜单信息
     * @return 结果
     */
    public boolean isParentView(SysMobileMenu menu)
    {
        return menu.getParentId().intValue() != 0 && UserConstants.TYPE_DIR.equals(menu.getMenuType());
    }

}
