package com.usky.system.service.impl;

import com.usky.system.domain.SysMobileRoleMenu;
import com.usky.system.domain.SysRole;
import com.usky.system.mapper.SysMobileRoleMenuMapper;
import com.usky.system.mapper.SysRoleMapper;
import com.usky.system.service.SysMobileRoleMenuService;
import com.usky.common.mybatis.core.AbstractCrudService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 移动端_角色和菜单关联表 服务实现类
 * </p>
 *
 * @author JCB
 * @since 2023-03-02
 */
@Service
public class SysMobileRoleMenuServiceImpl extends AbstractCrudService<SysMobileRoleMenuMapper, SysMobileRoleMenu> implements SysMobileRoleMenuService {

    @Autowired
    private SysRoleMapper roleMapper;

    @Autowired(required=false)
    private SysMobileRoleMenuMapper sysMobileRoleMenuMapper;

    /**
     * 新增保存角色信息
     *
     * @param role 角色信息
     * @return 结果
     */
    @Override
    @Transactional
    public int insertRole(SysRole role)
    {
        // 新增角色信息
        roleMapper.insertRole(role);
        return insertMobileRoleMenu(role);
    }

    /**
     * 新增移动端角色菜单信息
     *
     * @param role 角色对象
     */
    public int insertMobileRoleMenu(SysRole role)
    {
        int rows = 1;
        // 新增用户与角色管理
        List<SysMobileRoleMenu> list = new ArrayList<SysMobileRoleMenu>();
        if (null != role.getMenuIds() && role.getMenuIds().length > 0){
            for (Long menuId : role.getMenuIds())
            {
                SysMobileRoleMenu rm = new SysMobileRoleMenu();
                rm.setRoleId(role.getRoleId());
                rm.setMenuId(menuId);
                list.add(rm);
            }
        }
        if (list.size() > 0)
        {
            rows = sysMobileRoleMenuMapper.batchMobileRoleMenu(list);
        }
        return rows;
    }

    /**
     * 修改保存角色信息
     *
     * @param role 角色信息
     * @return 结果
     */
    @Override
    @Transactional
    public int updateRole(SysRole role)
    {
        // 修改角色信息
        roleMapper.updateRole(role);
        // 删除角色与菜单关联
        sysMobileRoleMenuMapper.deleteMobileRoleMenuByRoleId(role.getRoleId());
        return insertMobileRoleMenu(role);
    }
}
